Welcome to dragonfly-doe2's documentation!
===================================

.. image:: http://www.ladybug.tools/assets/img/dragonfly.png

`DOE-2 <https://www.doe2.com/>`_ extension for `dragonfly <https://github.com/ladybug-tools/dragonfly-core/>`_


Installation
============

``pip install -U dragonfly-doe2``.


dragonfly_doe2
=============

.. toctree::
  :maxdepth: 4

  modules

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
